/**
 * @file
 * Provides Slick Browser view exposed form utilitiy functions.
 */

(function ($, Drupal) {

  'use strict';

  /**
   * Slick Browser utility functions.
   *
   * @param {int} i
   *   The index of the current element.
   * @param {HTMLElement} el
   *   The form-radio HTML element.
   */
  function sbAutoSubmit(i, el) {
    var $el = $(el);
    var $view = $el.closest('.view--sb');
    var val = $el.find('.form-radio:checked').val().replace('_', '-');

    $view.addClass('view--sb-filter-' + val);
    if ($view.find('.view-empty').length) {
      $view.addClass('view--sb-filter-empty');
    }

    $el.find('.form-radio').each(function () {
      var $radio = $(this);
      val = $radio.val().replace('_', '-');

      $radio.on('change', function () {
        $view.removeClass('view--sb-filter-' + val);
        $view.addClass('view--sb-filter-' + val);

        $('.is-filter-checked', $el).removeClass('is-filter-checked');
        $radio.parent().addClass('is-filter-checked');

        $el.find('.form-submit').trigger('click');
      });
    });
  }

  /**
   * Attaches Slick Browser view exposed form behavior to HTML element.
   *
   * @type {Drupal~behavior}
   */
  Drupal.behaviors.slickBrowserAutoSubmit = {
    attach: function (context) {
      $('.sb__autosubmit', context).once('sbAutoSubmit').each(sbAutoSubmit);
    },
    detach: function (context, setting, trigger) {
      if (trigger === 'unload') {
        $(context).find('.sb__autosubmit').removeOnce('sbAutoSubmit');
      }
    }
  };

})(jQuery, Drupal);
